# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The user interface for the Ubuntu One Installer's SSO client."""

import ubuntu_sso.qt.gui as sso_gui

from ubuntuone_installer.gui.qt.gui import MainWindow


class UbuntuSSOClientGUI(object):
    """A custom Client GUI for SSO."""

    def __init__(self, app_name, tc_url, help_text,
                 window_id=0, login_only=False):
        """Create a new instance."""

        # create the controller and the ui, then set the cb and call the show
        # method so that we can work
        self.controller = sso_gui.UbuntuSSOWizardController(
            app_name,
            user_cancellation_callback=self._user_cancellation_callback)
        self.view = MainWindow()

        self.login_success_callback = lambda x, y: None
        self.registration_success_callback = lambda x, y: None
        self.user_cancellation_callback = lambda x: None

        self.view.loginSuccess.connect(self._login_success_callback)
        self.view.registrationSuccess.connect(
            self._registration_success_callback)
        self.view.userCancellation.connect(self._user_cancellation_callback)

        self.view.show()

    def _login_success_callback(self, app_name, email):
        """Call the real callback, set by the Credentials object"""
        self.login_success_callback(str(app_name), str(email))

    def _registration_success_callback(self, app_name, email):
        """Call the real callback, set by the Credentials object"""
        self.registration_success_callback(str(app_name), str(email))

    def _user_cancellation_callback(self, app_name):
        """Call the real callback, set by the Credentials object"""
        self.user_cancellation_callback(str(app_name))
