# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The test suite for the Qt UI of the Ubuntu One Installer."""

from ubuntuone_installer.tests import TestCase

import ubuntuone_installer.gui.qt.main.windows as main_module

# pylint: disable=W0212

from ubuntuone.platform.credentials import (
    APP_NAME,
    DESCRIPTION,
    TC_URL,
)


class FakeSSOCred(object):
    """A fake sso_cred."""

    _registered_to_signal = False
    _login_args = ()
    on_credentials_found = None

    def register_to_signals(self):
        """Fake method."""
        self._registered_to_signal = True

    def login_or_register_to_get_credentials(self, *args, **kwargs):
        """Fake method."""
        self._login_args = (args, kwargs)


class FakeSSOClient(object):

    """Fake UbuntuSSOClient."""

    sso_cred = FakeSSOCred()
    testcase = None

    def connect(self):
        """Fake method."""
        self.testcase._connected = True
        return self


class MainTestCase(TestCase):

    """Tests for the main() function."""

    _connected = False

    def setUp(self):
        """Prepare tests."""
        self.patch(main_module, "UbuntuSSOClient", FakeSSOClient)
        main_module.UbuntuSSOClient.testcase = self

    def test_connect(self):
        """Test that we instantiate the SSO Client and connect."""
        main_module.main()
        self.assertEqual(FakeSSOClient.testcase._connected, True)

    def test_credentials_found_cb(self):
        """Test that the credentials found signal is connected."""
        main_module.main()
        self.assertEqual(
            FakeSSOClient.sso_cred.on_credentials_found_cb.__name__,
            "stop")

    def test_registered(self):
        """Test that the credentials registers to signals."""
        main_module.main()
        self.assertEqual(FakeSSOClient.sso_cred._registered_to_signal,
            True)

    def test_check_register_args(self):
        """Test that the credentials registers to signals."""
        main_module.main()
        self.assertEqual(FakeSSOClient.sso_cred._login_args,
            ((APP_NAME, TC_URL, DESCRIPTION, 0),
            {'ui_module': 'ubuntuone_installer.gui.qt.embedded_sso'}))
