# -*- coding: utf-8 -*-

# Authors: Manuel de la Pena <manuel@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Reactor installation for windows."""

# pylint: disable=E1101, F0401, W0404

from twisted.internet.defer import inlineCallbacks
from ubuntu_sso.main.windows import UbuntuSSOClient

from ubuntuone.platform.credentials import (
    APP_NAME,
    DESCRIPTION,
    TC_URL,
)


@inlineCallbacks
def main():
    """Perform a client request to be logged in."""
    client = UbuntuSSOClient()
    client = yield client.connect()

    @inlineCallbacks
    def stop(*args):
        """End the process."""
        from twisted.internet import reactor
        yield client.sso_cred.unregister_to_signals()
        reactor.stop()

    client.sso_cred.on_credentials_found_cb = stop
    client.sso_cred.on_authorization_denied_cb = stop
    client.sso_cred.on_credentials_error_cb = stop
    yield client.sso_cred.register_to_signals()
    yield client.sso_cred.login_or_register_to_get_credentials(APP_NAME,
        TC_URL,
        DESCRIPTION, 0,
        ui_module="ubuntuone_installer.gui.qt.embedded_sso")
